# Guides

Tutorials and guides for using RAGLint.

```{toctree}
:maxdepth: 2

configuration
plugins
benchmarks
integrations
cost-tracking
deployment
```

## Available Guides

- [Configuration](configuration.md) - Configure RAGLint
- [Plugins](plugins.md) - Create custom metrics
- [Benchmarks](benchmarks.md) - Run benchmarks
- [Integrations](integrations.md) - LangChain integration
- [Cost Tracking](cost-tracking.md) - Monitor costs
- [Deployment](deployment.md) - Deploy with Docker
